import request from '@/utils/request'

// 查询岗位列表
export function listPost(query) {
  return request({
    url: '/system/post/list',
    method: 'get',
    params: query
  })
}

// 查询岗位详细
export function getPost(postId) {
  return request({
    url: '/system/post/' + postId,
    method: 'get'
  })
}

// 新增岗位
export function addPost(data) {
  return request({
    url: '/system/post',
    method: 'post',
    data: data
  })
}

// 修改岗位
export function updatePost(data) {
  return request({
    url: '/system/post',
    method: 'put',
    data: data
  })
}

// 删除岗位
export function delPost(postId) {
  return request({
    url: '/system/post/' + postId,
    method: 'delete'
  })
}

// 性质管理列表查询
export function getNature() {
  return request({
    url: '/system/nature/list',
    method: 'get'
  })
}

// 新增性质
export function addNature(data) {
  return request({
    url: '/system/nature',
    method: 'post',
    data: data
  })
}

// 删除性质
export function delNature(natureIds) {
  return request({
    url: '/system/nature/' + natureIds,
    method: 'delete'
  })
}

// 修改性质
export function updateNature(data) {
  return request({
    url: '/system/nature',
    method: 'put',
    data: data
  })
}

// 根据性质编号获取详细信息
export function getNatureByNatureId(natureId) {
  return request({
    url: '/system/nature/' + natureId,
    method: 'get'
  })
}

// 更新性质排序
export function updateSortNature(data) {
  return request({
    url: '/system/nature/updateSort',
    method: 'put',
    data: data
  })
}

// 更新岗位排序
export function updateSortPost(data) {
  return request({
    url: '/system/post/updateSort',
    method: 'put',
    data: data
  })
}